from django.db.models import Q, F
from django.utils import timezone

from services.models import IPResource

import re
from ipaddress import IPv4Address, AddressValueError


def fastpinger_update(f):
    regex = re.compile('^(?P<ip>[0-9.]+)[ ]+: (?P<p1>([0-9]+.[0-9]+|-)) (?P<p2>([0-9]+.[0-9]+|-))'
                       ' (?P<p3>([0-9]+.[0-9]+|-)) (?P<p4>([0-9]+.[0-9]+|-)) (?P<p5>([0-9]+.[0-9]+|-))$')
    up_count = IPResource.objects.filter(last_check__isnull=False).filter(last_time_up=F('last_check')).count()
    down_count = IPResource.objects.filter(last_check__isnull=False).exclude(last_time_up=F('last_check')).count()
    unknown_count = IPResource.objects.filter(last_check__isnull=True).count()

    up, down, unknown = set(), set(), set()
    for line in f:
        try:
            line = line.decode('utf-8')
        except UnicodeDecodeError:
            continue
        g = regex.match(line)
        if not g:
            continue
        try:
            ip = IPv4Address(g.group('ip'))
        except AddressValueError:
            continue
        p = [ g.group('p%d' % i) for i in [1, 2, 3, 4, 5] ]
        if all(map(lambda p: p == '-', p)):
            down.add(ip.compressed)
        else:
            up.add(ip.compressed)

    up = up - down # suppression des doublons

    up = IPResource.objects.filter(ip__in=up)
    down = IPResource.objects.filter(ip__in=down)
    unknown = IPResource.objects.exclude(Q(pk__in=up) | Q(pk__in=down))

    up.exclude(last_time_up=F('last_check')).count()
    down.filter(last_time_up=F('last_check')).count()

    now = timezone.now()

    up.update(last_time_up=now, last_check=now)
    down.update(last_check=now)

    upped = len(up) - up_count
    downed = len(down) - down_count
    unknowned = len(unknown) - unknown_count

    return "UP: %d (%+d), DOWN: %d (%+d), UNKNOWN: %d (%+d)" \
            % (len(up), upped, len(down), downed, len(unknown), unknowned)
